;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "no-littering" "20251011.1825"
  "Help keeping ~/.config/emacs clean."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/emacscollective/no-littering"
  :commit "09d07714904fc6185c0cf2599aa1b29d0f49f6e3"
  :revdesc "09d07714904f"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.no-littering@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.no-littering@jonas.bernoulli.dev")))
